==> apache-karaf-cave-3.0.0-src.zip: apache-karaf-cave-3.0.0/server/command/src/main/java/org/apache/karaf/cave/server/command/RepositoryDestroyCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.cave.server.command;

import org.apache.karaf.shell.commands.Argument;
import org.apache.karaf.shell.commands.Command;

/**
 * Destroy a Cave repository
 */
@Command(scope = "cave", name = "repository-destroy", description = "Destroy a Cave repository from the registry, including delete of storage")
public class RepositoryDestroyCommand extends CaveRepositoryCommandSupport {

    @Argument(index = 0, name = "name", description = "The name of the repository", required = true, multiValued = false)
    String name = null;

    protected Object doExecute() throws Exception {
        if (getCaveRepositoryService().getRepository(name) == null) {
            System.err.println("Cave repository " + name + " doesn't exist");
            return null;
        }
        getCaveRepositoryService().destroy(name);
        return null;
    }

}

==> apache-karaf-cave-4.0.0-src.zip: apache-karaf-cave-4.0.0/server/command/src/main/java/org/apache/karaf/cave/server/command/RepositoryDestroyCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.cave.server.command;

import org.apache.karaf.cave.server.command.completers.RepositoryCompleter;
import org.apache.karaf.shell.api.action.Argument;
import org.apache.karaf.shell.api.action.Command;
import org.apache.karaf.shell.api.action.Completion;
import org.apache.karaf.shell.api.action.Option;
import org.apache.karaf.shell.api.action.lifecycle.Service;

/**
 * Destroy a Cave repository
 */
@Command(scope = "cave", name = "repository-destroy", description = "Destroy a Cave repository from the registry, including delete of storage")
@Service
public class RepositoryDestroyCommand extends CaveRepositoryCommandSupport {

    @Argument(index = 0, name = "name", description = "The name of the repository", required = true, multiValued = false)
    @Completion(RepositoryCompleter.class)
    String name = null;

    @Option(name = "-s", aliases = "--storage", description = "Remove the repository from the backend storage (WARNING)", required = false, multiValued = false)
    boolean removeStorage = false;

    protected Object doExecute() throws Exception {
        if (getCaveRepositoryService().getRepository(name) == null) {
            System.err.println("Cave repository " + name + " doesn't exist");
            return null;
        }
        if (removeStorage)
            getCaveRepositoryService().destroy(name);
        else getCaveRepositoryService().remove(name);
        return null;
    }

}
